@@ -1,16 +1,23 @@
 #!/usr/bin/env python
 
-import xml.etree.ElementTree
+import os
+
+from .. import utils
 
 
 def load(fn):
-    e = xml.etree.ElementTree.parse(fn)
+    return utils.ETree(file=fn)
+
+
+def resolve_protocol(e):
+    if isinstance(e, (str, unicode)):
+        return load(os.path.expanduser(e))
     return e
 
 
 def parse_exp(v):
-    for c in ['(', ')', '+', '-', '/', '#GT', '#LT', \
-            '#AND', '#OR', '#NOT', '#LE', '#GE', '==']:
+    for c in ['(', ')', '+', '-', '/', '#GT', '#LT',
+              '#AND', '#OR', '#NOT', '#LE', '#GE', '==']:
         v = v.replace(c, ' ')
     return v.split()
 
